@@ -1,5 +1,4 @@
 import os
-import os
 import sys
 import textwrap
 import types
@@ -61,6 +60,7 @@ class OpenapiCommand(PluginCommand):
               openapi register filename NAME
               openapi register delete NAME
               openapi register list [NAME] [--output=OUTPUT]
+              openapi register protocol PROTOCOL
               openapi TODO merge [SERVICES...] [--dir=DIR] [--verbose]
               openapi TODO doc FILE --format=(txt|md)[--indent=INDENT]
               openapi TODO doc [SERVICES...] [--dir=DIR]
@@ -405,8 +405,10 @@ class OpenapiCommand(PluginCommand):
             result = registry.delete(name=arguments.NAME)
             if result == 0:
                 Console.error("Entry could not be found")
-            else:
+            elif result is not None:
                 Console.ok("Ok. Entry deleted")
+            else:
+                Console.error("Could not delete entry")
 
         elif arguments.register and arguments.list:
 
@@ -415,6 +417,10 @@ class OpenapiCommand(PluginCommand):
 
             registry.Print(data=result, output=arguments.output)
 
+        elif arguments.register and arguments.protocol:
+            result = Registry.protocol(protocol=arguments.PROTOCOL)
+            Console.ok(f"Using Registry Protocol: {result}")
+
         elif arguments.register and arguments['filename']:
 
             registry = Registry()
@@ -442,7 +448,10 @@ class OpenapiCommand(PluginCommand):
                               spec=path_expand(arguments.YAML),
                               foreground=arguments.fg)
 
-                print(f"Run PID: {pid}")
+                if pid is None:
+                    pass
+                else:
+                    print(f"Run PID: {pid}")
 
             except FileNotFoundError:
 
